==> segmentSeq_1.8.0.zip: segmentSeq/doc/segmentSeq.R <==
### R code from vignette source 'segmentSeq.Rnw'

###################################################
### code chunk number 1: segmentSeq.Rnw:25-26
###################################################
  library(segmentSeq)


###################################################
### code chunk number 2: segmentSeq.Rnw:31-33 (eval = FALSE)
###################################################
##   library(snow)
## cl <- makeCluster(8, "MPI")


###################################################
### code chunk number 3: segmentSeq.Rnw:37-38
###################################################
  cl <- NULL


###################################################
### code chunk number 4: segmentSeq.Rnw:43-52
###################################################
chrlens <- c(1e6, 2e5)

datadir <- system.file("extdata", package = "segmentSeq")
libfiles <- c("SL9.txt", "SL10.txt", "SL26.txt", "SL32.txt")
libnames <- c("SL9", "SL10", "SL26", "SL32")
replicates <- c("AGO6", "AGO6", "AGO4", "AGO4")

aD <- readGeneric(files = libfiles, dir = datadir, replicates = replicates, libnames = libnames, chrs = c(">Chr1", ">Chr2"), chrlens = chrlens, polyLength = 10, header = TRUE, gap = 200)
aD


###################################################
### code chunk number 5: segmentSeq.Rnw:57-59
###################################################
sD <- processAD(aD, cl = cl)
sD


###################################################
### code chunk number 6: segmentSeq.Rnw:68-70
###################################################
clustSegs <- heuristicSeg(sD = sD, aD = aD, RKPM = 300, largeness = 1e8, cl = cl)
clustSegs


###################################################
### code chunk number 7: segmentSeq.Rnw:82-84
###################################################
classSegs <- classifySeg(sD = sD, aD = aD, cD = clustSegs, subRegion = NULL, getLikes = TRUE, lociCutoff = 0.9, nullCutoff = 0.9, cl = cl)
classSegs


###################################################
### code chunk number 8: segPlot
###################################################
par(mfrow = c(2,1), mar = c(2,6,2,2))
plotGenome(aD, clustSegs, chr = ">Chr1", limits = c(1, 1e5), showNumber = FALSE, cap = 50)
plotGenome(aD, classSegs, chr = ">Chr1", limits = c(1, 1e5), showNumber = FALSE, cap = 50)


###################################################
### code chunk number 9: figSeg
###################################################
par(mfrow = c(2,1), mar = c(2,6,2,2))
plotGenome(aD, clustSegs, chr = ">Chr1", limits = c(1, 1e5), showNumber = FALSE, cap = 50)
plotGenome(aD, classSegs, chr = ">Chr1", limits = c(1, 1e5), showNumber = FALSE, cap = 50)

==> segmentSeq_1.12.1.zip: segmentSeq/doc/segmentSeq.R <==
### R code from vignette source 'segmentSeq.Rnw'

###################################################
### code chunk number 1: segmentSeq.Rnw:25-26
###################################################
  library(segmentSeq)


###################################################
### code chunk number 2: segmentSeq.Rnw:31-33 (eval = FALSE)
###################################################
##   library(snow)
## cl <- makeCluster(8, "MPI")


###################################################
### code chunk number 3: segmentSeq.Rnw:37-38
###################################################
  cl <- NULL


###################################################
### code chunk number 4: segmentSeq.Rnw:43-55
###################################################
chrlens <- c(1e6, 2e5)

datadir <- system.file("extdata", package = "segmentSeq")
libfiles <- c("SL9.txt", "SL10.txt", "SL26.txt", "SL32.txt")
libnames <- c("SL9", "SL10", "SL26", "SL32")
replicates <- c("AGO6", "AGO6", "AGO4", "AGO4")

aD <- readGeneric(files = libfiles, dir = datadir,
                  replicates = replicates, libnames = libnames, 
                  chrs = c(">Chr1", ">Chr2"), chrlens = chrlens,
                  polyLength = 10, header = TRUE, gap = 200)
aD


###################################################
### code chunk number 5: segmentSeq.Rnw:60-62
###################################################
sD <- processAD(aD, gap = 100, cl = cl)
sD


###################################################
### code chunk number 6: segmentSeq.Rnw:71-73
###################################################
clustSegs <- heuristicSeg(sD = sD, aD = aD, RKPM = 300, largeness = 1e8, cl = cl)
clustSegs


###################################################
### code chunk number 7: segmentSeq.Rnw:85-89
###################################################
classSegs <- classifySeg(sD = sD, aD = aD, cD = clustSegs,
                         subRegion = NULL, getLikes = TRUE,
                         lociCutoff = 0.9, nullCutoff = 0.9, cl = cl)
classSegs


###################################################
### code chunk number 8: segPlot
###################################################
par(mfrow = c(2,1), mar = c(2,6,2,2))
plotGenome(aD, clustSegs, chr = ">Chr1", limits = c(1, 1e5),
           showNumber = FALSE, cap = 50)
plotGenome(aD, classSegs, chr = ">Chr1", limits = c(1, 1e5),
           showNumber = FALSE, cap = 50)


###################################################
### code chunk number 9: figSeg
###################################################
par(mfrow = c(2,1), mar = c(2,6,2,2))
plotGenome(aD, clustSegs, chr = ">Chr1", limits = c(1, 1e5),
           showNumber = FALSE, cap = 50)
plotGenome(aD, classSegs, chr = ">Chr1", limits = c(1, 1e5),
           showNumber = FALSE, cap = 50)
